import pydantic
import typing
import typing_extensions

from .v1_face_detection_create_body_assets import (
    V1FaceDetectionCreateBodyAssets,
    _SerializerV1FaceDetectionCreateBodyAssets,
)


class V1FaceDetectionCreateBody(typing_extensions.TypedDict):
    """
    V1FaceDetectionCreateBody
    """

    assets: typing_extensions.Required[V1FaceDetectionCreateBodyAssets]
    """
    Provide the assets for face detection
    """

    confidence_score: typing_extensions.NotRequired[float]
    """
    Confidence threshold for filtering detected faces. 
    * Higher values (e.g., 0.9) include only faces detected with high certainty, reducing false positives. 
    * Lower values (e.g., 0.3) include more faces, but may increase the chance of incorrect detections.
    """


class _SerializerV1FaceDetectionCreateBody(pydantic.BaseModel):
    """
    Serializer for V1FaceDetectionCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1FaceDetectionCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    confidence_score: typing.Optional[float] = pydantic.Field(
        alias="confidence_score", default=None
    )



import pydantic
import typing
import typing_extensions

from .v1_video_projects_get_response_download import V1VideoProjectsGetResponseDownload
from .v1_video_projects_get_response_downloads_item import (
    V1VideoProjectsGetResponseDownloadsItem,
)
from .v1_video_projects_get_response_error import V1VideoProjectsGetResponseError


class V1VideoProjectsGetResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    created_at: str = pydantic.Field(
        alias="created_at",
    )
    credits_charged: int = pydantic.Field(
        alias="credits_charged",
    )
    """
    The amount of credits deducted from your account to generate the video. If the status is not 'complete', this value is an estimate and may be adjusted upon completion based on the actual FPS of the output video. 
    
    If video generation fails, credits will be refunded, and this field will be updated to include the refund.
    """
    download: typing.Optional[V1VideoProjectsGetResponseDownload] = pydantic.Field(
        alias="download",
    )
    """
    Deprecated: Please use `.downloads` instead. The download url and expiration date of the video project
    """
    downloads: typing.List[V1VideoProjectsGetResponseDownloadsItem] = pydantic.Field(
        alias="downloads",
    )
    enabled: bool = pydantic.Field(
        alias="enabled",
    )
    """
    Indicates whether the resource is deleted
    """
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    """
    The end time of the input video in seconds
    """
    error: typing.Optional[V1VideoProjectsGetResponseError] = pydantic.Field(
        alias="error",
    )
    """
    In the case of an error, this object will contain the error encountered during video render
    """
    fps: float = pydantic.Field(
        alias="fps",
    )
    """
    Frame rate of the video. If the status is not 'complete', the frame rate is an estimate and will be adjusted when the video completes.
    """
    height: int = pydantic.Field(
        alias="height",
    )
    """
    The height of the final output video. A value of -1 indicates the height can be ignored.
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    Unique ID of the video. This value can be used in the [get video project API](https://docs.magichour.ai/api-reference/video-projects/get-video-details) to fetch additional details such as status
    """
    name: typing.Optional[str] = pydantic.Field(
        alias="name",
    )
    """
    The name of the video.
    """
    start_seconds: float = pydantic.Field(
        alias="start_seconds",
    )
    """
    The start time of the input video in seconds
    """
    status: typing_extensions.Literal[
        "canceled", "complete", "draft", "error", "queued", "rendering"
    ] = pydantic.Field(
        alias="status",
    )
    """
    The status of the video.
    """
    total_frame_cost: int = pydantic.Field(
        alias="total_frame_cost",
    )
    """
    Deprecated: Previously represented the number of frames (original name of our credit system) used for video generation. Use 'credits_charged' instead.
    
    The amount of frames used to generate the video. If the status is not 'complete', the cost is an estimate and will be adjusted when the video completes.
    """
    type_: str = pydantic.Field(
        alias="type",
    )
    """
    The type of the video project. Possible values are ANIMATION, IMAGE_TO_VIDEO, VIDEO_TO_VIDEO, TEXT_TO_VIDEO, FACE_SWAP, LIP_SYNC, AUTO_SUBTITLE, TALKING_PHOTO
    """
    width: int = pydantic.Field(
        alias="width",
    )
    """
    The width of the final output video. A value of -1 indicates the width can be ignored.
    """



import enum
import typing


class Environment(enum.Enum):
    """Pre-defined base URLs for the API"""

    ENVIRONMENT = "https://api.magichour.ai"
    MOCK_SERVER = "https://api.sideko.dev/v1/mock/magichour/magic-hour/0.33.0"


def _get_base_url(
    *, base_url: typing.Optional[str] = None, environment: Environment
) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Must include a base_url or environment arguments")



import pydantic
import typing
import typing_extensions

from .v1_face_detection_get_response_faces_item import (
    V1FaceDetectionGetResponseFacesItem,
)


class V1FaceDetectionGetResponse(pydantic.BaseModel):
    """
    V1FaceDetectionGetResponse
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    credits_charged: int = pydantic.Field(
        alias="credits_charged",
    )
    """
    The credits charged for the task.
    """
    faces: typing.List[V1FaceDetectionGetResponseFacesItem] = pydantic.Field(
        alias="faces",
    )
    """
    The faces detected in the image or video. The list is populated as faces are detected.
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    The id of the task
    """
    status: typing_extensions.Literal["complete", "error", "queued", "rendering"] = (
        pydantic.Field(
            alias="status",
        )
    )
    """
    The status of the detection.
    """



import pydantic
import typing
import typing_extensions


class V1LipSyncCreateBodyAssets(typing_extensions.TypedDict):
    """
    Provide the assets for lip-sync. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
    """

    audio_file_path: typing_extensions.Required[str]
    """
    The path of the audio file. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """

    video_file_path: typing_extensions.NotRequired[str]
    """
    The path of the input video. This field is required if `video_source` is `file`. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """

    video_source: typing_extensions.Required[
        typing_extensions.Literal["file", "youtube"]
    ]

    youtube_url: typing_extensions.NotRequired[str]
    """
    Using a youtube video as the input source. This field is required if `video_source` is `youtube`
    """


class _SerializerV1LipSyncCreateBodyAssets(pydantic.BaseModel):
    """
    Serializer for V1LipSyncCreateBodyAssets handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    audio_file_path: str = pydantic.Field(
        alias="audio_file_path",
    )
    video_file_path: typing.Optional[str] = pydantic.Field(
        alias="video_file_path", default=None
    )
    video_source: typing_extensions.Literal["file", "youtube"] = pydantic.Field(
        alias="video_source",
    )
    youtube_url: typing.Optional[str] = pydantic.Field(
        alias="youtube_url", default=None
    )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AutoSubtitleGeneratorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1AutoSubtitleGeneratorCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        style: params.V1AutoSubtitleGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AutoSubtitleGeneratorCreateResponse:
        """
        Auto Subtitle Generator

        Automatically generate subtitles for your video in multiple languages.

        POST /v1/auto-subtitle-generator

        Args:
            name: The name of video
            assets: Provide the assets for auto subtitle generator
            end_seconds: The end time of the input video in seconds
            start_seconds: The start time of the input video in seconds
            style: Style of the subtitle. At least one of `.style.template` or `.style.custom_config` must be provided.
        * If only `.style.template` is provided, default values for the template will be used.
        * If both are provided, the fields in `.style.custom_config` will be used to overwrite the fields in `.style.template`.
        * If only `.style.custom_config` is provided, then all fields in `.style.custom_config` will be used.

        To use custom config only, the following `custom_config` params are required:
        * `.style.custom_config.font`
        * `.style.custom_config.text_color`
        * `.style.custom_config.vertical_position`
        * `.style.custom_config.horizontal_position`

            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.auto_subtitle_generator.create(
            assets={"video_file_path": "api-assets/id/1234.mp4"},
            end_seconds=15.0,
            start_seconds=0.0,
            style={},
            name="Auto Subtitle video",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
                "style": style,
            },
            dump_with=params._SerializerV1AutoSubtitleGeneratorCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/auto-subtitle-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AutoSubtitleGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAutoSubtitleGeneratorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1AutoSubtitleGeneratorCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        style: params.V1AutoSubtitleGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AutoSubtitleGeneratorCreateResponse:
        """
        Auto Subtitle Generator

        Automatically generate subtitles for your video in multiple languages.

        POST /v1/auto-subtitle-generator

        Args:
            name: The name of video
            assets: Provide the assets for auto subtitle generator
            end_seconds: The end time of the input video in seconds
            start_seconds: The start time of the input video in seconds
            style: Style of the subtitle. At least one of `.style.template` or `.style.custom_config` must be provided.
        * If only `.style.template` is provided, default values for the template will be used.
        * If both are provided, the fields in `.style.custom_config` will be used to overwrite the fields in `.style.template`.
        * If only `.style.custom_config` is provided, then all fields in `.style.custom_config` will be used.

        To use custom config only, the following `custom_config` params are required:
        * `.style.custom_config.font`
        * `.style.custom_config.text_color`
        * `.style.custom_config.vertical_position`
        * `.style.custom_config.horizontal_position`

            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.auto_subtitle_generator.create(
            assets={"video_file_path": "api-assets/id/1234.mp4"},
            end_seconds=15.0,
            start_seconds=0.0,
            style={},
            name="Auto Subtitle video",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
                "style": style,
            },
            dump_with=params._SerializerV1AutoSubtitleGeneratorCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/auto-subtitle-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AutoSubtitleGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic


class V1AiQrCodeGeneratorCreateResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    credits_charged: int = pydantic.Field(
        alias="credits_charged",
    )
    """
    The amount of credits deducted from your account to generate the image. We charge credits right when the request is made. 
    
    If an error occurred while generating the image(s), credits will be refunded and this field will be updated to include the refund.
    """
    frame_cost: int = pydantic.Field(
        alias="frame_cost",
    )
    """
    Deprecated: Previously represented the number of frames (original name of our credit system) used for image generation. Use 'credits_charged' instead.
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    Unique ID of the image. This value can be used in the [get image project API](https://docs.magichour.ai/api-reference/image-projects/get-image-details) to fetch additional details such as status
    """



import pydantic
import typing
import typing_extensions

from .v1_ai_image_upscaler_create_body_assets import (
    V1AiImageUpscalerCreateBodyAssets,
    _SerializerV1AiImageUpscalerCreateBodyAssets,
)
from .v1_ai_image_upscaler_create_body_style import (
    V1AiImageUpscalerCreateBodyStyle,
    _SerializerV1AiImageUpscalerCreateBodyStyle,
)


class V1AiImageUpscalerCreateBody(typing_extensions.TypedDict):
    """
    V1AiImageUpscalerCreateBody
    """

    assets: typing_extensions.Required[V1AiImageUpscalerCreateBodyAssets]
    """
    Provide the assets for upscaling
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    scale_factor: typing_extensions.Required[float]
    """
    How much to scale the image. Must be either 2 or 4
    """

    style: typing_extensions.Required[V1AiImageUpscalerCreateBodyStyle]


class _SerializerV1AiImageUpscalerCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiImageUpscalerCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AiImageUpscalerCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    scale_factor: float = pydantic.Field(
        alias="scale_factor",
    )
    style: _SerializerV1AiImageUpscalerCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic


class V1FaceDetectionGetResponseFacesItem(pydantic.BaseModel):
    """
    V1FaceDetectionGetResponseFacesItem
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    path: str = pydantic.Field(
        alias="path",
    )
    """
    The path to the face image. This should be used in face swap photo/video API calls as `.assets.face_mappings.original_face`
    """
    url: str = pydantic.Field(
        alias="url",
    )
    """
    The url to the face image. This is used to render the image in your applications.
    """



import pydantic
import typing
import typing_extensions

from .v1_auto_subtitle_generator_create_body_style_custom_config import (
    V1AutoSubtitleGeneratorCreateBodyStyleCustomConfig,
    _SerializerV1AutoSubtitleGeneratorCreateBodyStyleCustomConfig,
)


class V1AutoSubtitleGeneratorCreateBodyStyle(typing_extensions.TypedDict):
    """
    Style of the subtitle. At least one of `.style.template` or `.style.custom_config` must be provided.
    * If only `.style.template` is provided, default values for the template will be used.
    * If both are provided, the fields in `.style.custom_config` will be used to overwrite the fields in `.style.template`.
    * If only `.style.custom_config` is provided, then all fields in `.style.custom_config` will be used.

    To use custom config only, the following `custom_config` params are required:
    * `.style.custom_config.font`
    * `.style.custom_config.text_color`
    * `.style.custom_config.vertical_position`
    * `.style.custom_config.horizontal_position`

    """

    custom_config: typing_extensions.NotRequired[
        V1AutoSubtitleGeneratorCreateBodyStyleCustomConfig
    ]
    """
    Custom subtitle configuration.
    """

    template: typing_extensions.NotRequired[
        typing_extensions.Literal["cinematic", "highlight", "karaoke", "minimalist"]
    ]
    """
    Preset subtitle templates. Please visit https://magichour.ai/create/auto-subtitle-generator to see the style of the existing templates.
    """


class _SerializerV1AutoSubtitleGeneratorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AutoSubtitleGeneratorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    custom_config: typing.Optional[
        _SerializerV1AutoSubtitleGeneratorCreateBodyStyleCustomConfig
    ] = pydantic.Field(alias="custom_config", default=None)
    template: typing.Optional[
        typing_extensions.Literal["cinematic", "highlight", "karaoke", "minimalist"]
    ] = pydantic.Field(alias="template", default=None)



import pydantic
import typing
import typing_extensions

from .v1_face_swap_photo_create_body_assets_face_mappings_item import (
    V1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem,
    _SerializerV1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem,
)


class V1FaceSwapPhotoCreateBodyAssets(typing_extensions.TypedDict):
    """
    Provide the assets for face swap photo
    """

    face_mappings: typing_extensions.NotRequired[
        typing.List[V1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem]
    ]
    """
    This is the array of face mappings used for multiple face swap. The value is required if `face_swap_mode` is `individual-faces`.
    """

    face_swap_mode: typing_extensions.NotRequired[
        typing_extensions.Literal["all-faces", "individual-faces"]
    ]
    """
    The mode of face swap.
    * `all-faces` - Swap all faces in the target image or video. `source_file_path` is required.
    * `individual-faces` - Swap individual faces in the target image or video. `source_faces` is required.
    """

    source_file_path: typing_extensions.NotRequired[str]
    """
    This is the image from which the face is extracted. The value is required if `face_swap_mode` is `all-faces`.
    
    This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """

    target_file_path: typing_extensions.Required[str]
    """
    This is the image where the face from the source image will be placed. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """


class _SerializerV1FaceSwapPhotoCreateBodyAssets(pydantic.BaseModel):
    """
    Serializer for V1FaceSwapPhotoCreateBodyAssets handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    face_mappings: typing.Optional[
        typing.List[_SerializerV1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem]
    ] = pydantic.Field(alias="face_mappings", default=None)
    face_swap_mode: typing.Optional[
        typing_extensions.Literal["all-faces", "individual-faces"]
    ] = pydantic.Field(alias="face_swap_mode", default=None)
    source_file_path: typing.Optional[str] = pydantic.Field(
        alias="source_file_path", default=None
    )
    target_file_path: str = pydantic.Field(
        alias="target_file_path",
    )



import pydantic


class V1FaceSwapCreateResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    credits_charged: int = pydantic.Field(
        alias="credits_charged",
    )
    """
    The amount of credits deducted from your account to generate the video. If the status is not 'complete', this value is an estimate and may be adjusted upon completion based on the actual FPS of the output video. 
    
    If video generation fails, credits will be refunded, and this field will be updated to include the refund.
    """
    estimated_frame_cost: int = pydantic.Field(
        alias="estimated_frame_cost",
    )
    """
    Deprecated: Previously represented the number of frames (original name of our credit system) used for video generation. Use 'credits_charged' instead.
    
    The amount of frames used to generate the video. If the status is not 'complete', the cost is an estimate and will be adjusted when the video completes.
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    Unique ID of the video. This value can be used in the [get video project API](https://docs.magichour.ai/api-reference/video-projects/get-video-details) to fetch additional details such as status
    """



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class FaceDetectionClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def get(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> models.V1FaceDetectionGetResponse:
        """
        Get face detection details

        Get the details of a face detection task.

        GET /v1/face-detection/{id}

        Args:
            id: The id of the task
            request_options: Additional options to customize the HTTP request

        Returns:
            200

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.face_detection.get(id="string")
        ```
        """
        return self._base_client.request(
            method="GET",
            path=f"/v1/face-detection/{id}",
            auth_names=["bearerAuth"],
            cast_to=models.V1FaceDetectionGetResponse,
            request_options=request_options or default_request_options(),
        )

    def create(
        self,
        *,
        assets: params.V1FaceDetectionCreateBodyAssets,
        confidence_score: typing.Union[
            typing.Optional[float], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1FaceDetectionCreateResponse:
        """
        Face Detection

        Detect faces in an image or video.

        Note: Face detection is free to use for the near future. Pricing may change in the future.

        POST /v1/face-detection

        Args:
            confidence_score: Confidence threshold for filtering detected faces.
        * Higher values (e.g., 0.9) include only faces detected with high certainty, reducing false positives.
        * Lower values (e.g., 0.3) include more faces, but may increase the chance of incorrect detections.
            assets: Provide the assets for face detection
            request_options: Additional options to customize the HTTP request

        Returns:
            200

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.face_detection.create(
            assets={"target_file_path": "api-assets/id/1234.png"}, confidence_score=0.5
        )
        ```
        """
        _json = to_encodable(
            item={"confidence_score": confidence_score, "assets": assets},
            dump_with=params._SerializerV1FaceDetectionCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/face-detection",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1FaceDetectionCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncFaceDetectionClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def get(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> models.V1FaceDetectionGetResponse:
        """
        Get face detection details

        Get the details of a face detection task.

        GET /v1/face-detection/{id}

        Args:
            id: The id of the task
            request_options: Additional options to customize the HTTP request

        Returns:
            200

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.face_detection.get(id="string")
        ```
        """
        return await self._base_client.request(
            method="GET",
            path=f"/v1/face-detection/{id}",
            auth_names=["bearerAuth"],
            cast_to=models.V1FaceDetectionGetResponse,
            request_options=request_options or default_request_options(),
        )

    async def create(
        self,
        *,
        assets: params.V1FaceDetectionCreateBodyAssets,
        confidence_score: typing.Union[
            typing.Optional[float], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1FaceDetectionCreateResponse:
        """
        Face Detection

        Detect faces in an image or video.

        Note: Face detection is free to use for the near future. Pricing may change in the future.

        POST /v1/face-detection

        Args:
            confidence_score: Confidence threshold for filtering detected faces.
        * Higher values (e.g., 0.9) include only faces detected with high certainty, reducing false positives.
        * Lower values (e.g., 0.3) include more faces, but may increase the chance of incorrect detections.
            assets: Provide the assets for face detection
            request_options: Additional options to customize the HTTP request

        Returns:
            200

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.face_detection.create(
            assets={"target_file_path": "api-assets/id/1234.png"}, confidence_score=0.5
        )
        ```
        """
        _json = to_encodable(
            item={"confidence_score": confidence_score, "assets": assets},
            dump_with=params._SerializerV1FaceDetectionCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/face-detection",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1FaceDetectionCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic


class V1FilesUploadUrlsCreateResponseItemsItem(pydantic.BaseModel):
    """
    V1FilesUploadUrlsCreateResponseItemsItem
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    expires_at: str = pydantic.Field(
        alias="expires_at",
    )
    """
    when the upload url expires, and will need to request a new one.
    """
    file_path: str = pydantic.Field(
        alias="file_path",
    )
    """
    this value is used in APIs that needs assets, such as image_file_path, video_file_path, and audio_file_path
    """
    upload_url: str = pydantic.Field(
        alias="upload_url",
    )
    """
    Used to upload the file to storage, send a PUT request with the file as data to upload.
    """



from .api_error import ApiError
from .auth import (
    AuthKey,
    AuthBasic,
    AuthBearer,
    AuthProvider,
    GrantType,
    OAuth2,
    OAuth2ClientCredentials,
    OAuth2Password,
)
from .base_client import AsyncBaseClient, BaseClient, SyncBaseClient
from .binary_response import BinaryResponse
from .query import encode_query_param, QueryParams
from .request import (
    filter_not_given,
    to_content,
    to_encodable,
    to_form_urlencoded,
    RequestOptions,
    default_request_options,
)
from .response import from_encodable, AsyncStreamResponse, StreamResponse

__all__ = [
    "ApiError",
    "AsyncBaseClient",
    "BaseClient",
    "BinaryResponse",
    "RequestOptions",
    "default_request_options",
    "SyncBaseClient",
    "AuthKey",
    "AuthBasic",
    "AuthBearer",
    "AuthProvider",
    "GrantType",
    "OAuth2",
    "OAuth2ClientCredentials",
    "OAuth2Password",
    "to_encodable",
    "to_form_urlencoded",
    "filter_not_given",
    "to_content",
    "encode_query_param",
    "from_encodable",
    "AsyncStreamResponse",
    "StreamResponse",
    "QueryParams",
]



import pydantic
import typing
import typing_extensions

from .v1_auto_subtitle_generator_create_body_assets import (
    V1AutoSubtitleGeneratorCreateBodyAssets,
    _SerializerV1AutoSubtitleGeneratorCreateBodyAssets,
)
from .v1_auto_subtitle_generator_create_body_style import (
    V1AutoSubtitleGeneratorCreateBodyStyle,
    _SerializerV1AutoSubtitleGeneratorCreateBodyStyle,
)


class V1AutoSubtitleGeneratorCreateBody(typing_extensions.TypedDict):
    """
    V1AutoSubtitleGeneratorCreateBody
    """

    assets: typing_extensions.Required[V1AutoSubtitleGeneratorCreateBodyAssets]
    """
    Provide the assets for auto subtitle generator
    """

    end_seconds: typing_extensions.Required[float]
    """
    The end time of the input video in seconds
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    start_seconds: typing_extensions.Required[float]
    """
    The start time of the input video in seconds
    """

    style: typing_extensions.Required[V1AutoSubtitleGeneratorCreateBodyStyle]
    """
    Style of the subtitle. At least one of `.style.template` or `.style.custom_config` must be provided. 
    * If only `.style.template` is provided, default values for the template will be used.
    * If both are provided, the fields in `.style.custom_config` will be used to overwrite the fields in `.style.template`.
    * If only `.style.custom_config` is provided, then all fields in `.style.custom_config` will be used.
    
    To use custom config only, the following `custom_config` params are required:
    * `.style.custom_config.font`
    * `.style.custom_config.text_color`
    * `.style.custom_config.vertical_position`
    * `.style.custom_config.horizontal_position`
    
    """


class _SerializerV1AutoSubtitleGeneratorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AutoSubtitleGeneratorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AutoSubtitleGeneratorCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    start_seconds: float = pydantic.Field(
        alias="start_seconds",
    )
    style: _SerializerV1AutoSubtitleGeneratorCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic


class V1FaceDetectionCreateResponse(pydantic.BaseModel):
    """
    V1FaceDetectionCreateResponse
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    credits_charged: int = pydantic.Field(
        alias="credits_charged",
    )
    """
    The credits charged for the task.
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    The id of the task
    """



import pydantic
import typing_extensions


class V1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem(typing_extensions.TypedDict):
    """
    V1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem
    """

    new_face: typing_extensions.Required[str]
    """
    The face image that will be used to replace the face in the `original_face`. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """

    original_face: typing_extensions.Required[str]
    """
    The face detected from the image in `target_file_path`. The file name is in the format of `<face_frame>-<face_index>.png`. This value is corresponds to the response in the [face detection API](https://docs.magichour.ai/api-reference/files/get-face-detection-details).
    
    * The face_frame is the frame number of the face in the target image. For images, the frame number is always 0.
    * The face_index is the index of the face in the target image, starting from 0 going left to right.
    """


class _SerializerV1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem(pydantic.BaseModel):
    """
    Serializer for V1FaceSwapPhotoCreateBodyAssetsFaceMappingsItem handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    new_face: str = pydantic.Field(
        alias="new_face",
    )
    original_face: str = pydantic.Field(
        alias="original_face",
    )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiClothesChangerClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1AiClothesChangerCreateBodyAssets,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiClothesChangerCreateResponse:
        """
        AI Clothes Changer

        Change outfits in photos in seconds with just a photo reference. Each photo costs 25 credits.

        POST /v1/ai-clothes-changer

        Args:
            name: The name of image
            assets: Provide the assets for clothes changer
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_clothes_changer.create(
            assets={
                "garment_file_path": "api-assets/id/outfit.png",
                "garment_type": "dresses",
                "person_file_path": "api-assets/id/model.png",
            },
            name="Clothes Changer image",
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "assets": assets},
            dump_with=params._SerializerV1AiClothesChangerCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-clothes-changer",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiClothesChangerCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiClothesChangerClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1AiClothesChangerCreateBodyAssets,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiClothesChangerCreateResponse:
        """
        AI Clothes Changer

        Change outfits in photos in seconds with just a photo reference. Each photo costs 25 credits.

        POST /v1/ai-clothes-changer

        Args:
            name: The name of image
            assets: Provide the assets for clothes changer
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_clothes_changer.create(
            assets={
                "garment_file_path": "api-assets/id/outfit.png",
                "garment_type": "dresses",
                "person_file_path": "api-assets/id/model.png",
            },
            name="Clothes Changer image",
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "assets": assets},
            dump_with=params._SerializerV1AiClothesChangerCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-clothes-changer",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiClothesChangerCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing
import typing_extensions


class V1AiImageGeneratorCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1AiImageGeneratorCreateBodyStyle
    """

    prompt: typing_extensions.Required[str]
    """
    The prompt used for the image.
    """

    tool: typing_extensions.NotRequired[
        typing_extensions.Literal[
            "ai-anime-generator",
            "ai-art-generator",
            "ai-background-generator",
            "ai-character-generator",
            "ai-face-generator",
            "ai-fashion-generator",
            "ai-icon-generator",
            "ai-illustration-generator",
            "ai-interior-design-generator",
            "ai-landscape-generator",
            "ai-logo-generator",
            "ai-manga-generator",
            "ai-outfit-generator",
            "ai-pattern-generator",
            "ai-photo-generator",
            "ai-sketch-generator",
            "ai-tattoo-generator",
            "album-cover-generator",
            "animated-characters-generator",
            "architecture-generator",
            "book-cover-generator",
            "comic-book-generator",
            "dark-fantasy-ai",
            "disney-ai-generator",
            "dnd-ai-art-generator",
            "emoji-generator",
            "fantasy-map-generator",
            "general",
            "graffiti-generator",
            "movie-poster-generator",
            "optical-illusion-generator",
            "pokemon-generator",
            "south-park-character-generator",
            "superhero-generator",
            "thumbnail-maker",
        ]
    ]
    """
    The art style to use for image generation. Defaults to 'general' if not provided.
    """


class _SerializerV1AiImageGeneratorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiImageGeneratorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    prompt: str = pydantic.Field(
        alias="prompt",
    )
    tool: typing.Optional[
        typing_extensions.Literal[
            "ai-anime-generator",
            "ai-art-generator",
            "ai-background-generator",
            "ai-character-generator",
            "ai-face-generator",
            "ai-fashion-generator",
            "ai-icon-generator",
            "ai-illustration-generator",
            "ai-interior-design-generator",
            "ai-landscape-generator",
            "ai-logo-generator",
            "ai-manga-generator",
            "ai-outfit-generator",
            "ai-pattern-generator",
            "ai-photo-generator",
            "ai-sketch-generator",
            "ai-tattoo-generator",
            "album-cover-generator",
            "animated-characters-generator",
            "architecture-generator",
            "book-cover-generator",
            "comic-book-generator",
            "dark-fantasy-ai",
            "disney-ai-generator",
            "dnd-ai-art-generator",
            "emoji-generator",
            "fantasy-map-generator",
            "general",
            "graffiti-generator",
            "movie-poster-generator",
            "optical-illusion-generator",
            "pokemon-generator",
            "south-park-character-generator",
            "superhero-generator",
            "thumbnail-maker",
        ]
    ] = pydantic.Field(alias="tool", default=None)



import pydantic
import typing
import typing_extensions

from .v1_ai_clothes_changer_create_body_assets import (
    V1AiClothesChangerCreateBodyAssets,
    _SerializerV1AiClothesChangerCreateBodyAssets,
)


class V1AiClothesChangerCreateBody(typing_extensions.TypedDict):
    """
    V1AiClothesChangerCreateBody
    """

    assets: typing_extensions.Required[V1AiClothesChangerCreateBodyAssets]
    """
    Provide the assets for clothes changer
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """


class _SerializerV1AiClothesChangerCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiClothesChangerCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AiClothesChangerCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)



import pydantic
import typing
import typing_extensions


class V1AiTalkingPhotoCreateBodyStyle(typing_extensions.TypedDict):
    """
    Attributes used to dictate the style of the output
    """

    generation_mode: typing_extensions.NotRequired[
        typing_extensions.Literal["expressive", "stable"]
    ]
    """
    Controls overall motion style.
    * `expressive` - More motion and facial expressiveness; may introduce visual artifacts.
    * `stable` -  Reduced motion for cleaner output; may result in minimal animation.
    """

    intensity: typing_extensions.NotRequired[float]
    """
    Note: this value is only applicable when generation_mode is `expressive`. The value can include up to 2 decimal places.
    * Lower values yield more stability but can suppress mouth movement.
    * Higher values increase motion and expressiveness, with a higher risk of distortion.
    """


class _SerializerV1AiTalkingPhotoCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiTalkingPhotoCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    generation_mode: typing.Optional[
        typing_extensions.Literal["expressive", "stable"]
    ] = pydantic.Field(alias="generation_mode", default=None)
    intensity: typing.Optional[float] = pydantic.Field(alias="intensity", default=None)



import pydantic
import typing
import typing_extensions

from .v1_image_projects_get_response_downloads_item import (
    V1ImageProjectsGetResponseDownloadsItem,
)
from .v1_image_projects_get_response_error import V1ImageProjectsGetResponseError


class V1ImageProjectsGetResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    created_at: str = pydantic.Field(
        alias="created_at",
    )
    credits_charged: int = pydantic.Field(
        alias="credits_charged",
    )
    """
    The amount of credits deducted from your account to generate the image. We charge credits right when the request is made. 
    
    If an error occurred while generating the image(s), credits will be refunded and this field will be updated to include the refund.
    """
    downloads: typing.List[V1ImageProjectsGetResponseDownloadsItem] = pydantic.Field(
        alias="downloads",
    )
    enabled: bool = pydantic.Field(
        alias="enabled",
    )
    """
    Indicates whether the resource is deleted
    """
    error: typing.Optional[V1ImageProjectsGetResponseError] = pydantic.Field(
        alias="error",
    )
    """
    In the case of an error, this object will contain the error encountered during video render
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    Unique ID of the image. This value can be used in the [get image project API](https://docs.magichour.ai/api-reference/image-projects/get-image-details) to fetch additional details such as status
    """
    image_count: int = pydantic.Field(
        alias="image_count",
    )
    """
    Number of images generated
    """
    name: typing.Optional[str] = pydantic.Field(
        alias="name",
    )
    """
    The name of the image.
    """
    status: typing_extensions.Literal[
        "canceled", "complete", "draft", "error", "queued", "rendering"
    ] = pydantic.Field(
        alias="status",
    )
    """
    The status of the image.
    """
    total_frame_cost: int = pydantic.Field(
        alias="total_frame_cost",
    )
    """
    Deprecated: Previously represented the number of frames (original name of our credit system) used for image generation. Use 'credits_charged' instead.
    """
    type_: str = pydantic.Field(
        alias="type",
    )
    """
    The type of the image project. Possible values are AI_HEADSHOT, AI_IMAGE, IMAGE_UPSCALER, FACE_SWAP, PHOTO_EDITOR, QR_CODE, BACKGROUND_REMOVER, CLOTHES_CHANGER, AI_MEME, FACE_EDITOR, PHOTO_COLORIZER, AI_GIF, AI_SELFIE, AI_IMAGE_EDITOR
    """



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiTalkingPhotoClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1AiTalkingPhotoCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        style: typing.Union[
            typing.Optional[params.V1AiTalkingPhotoCreateBodyStyle], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiTalkingPhotoCreateResponse:
        """
        AI Talking Photo

        Create a talking photo from an image and audio or text input.

        POST /v1/ai-talking-photo

        Args:
            name: The name of image
            style: Attributes used to dictate the style of the output
            assets: Provide the assets for creating a talking photo
            end_seconds: The end time of the input audio in seconds. The maximum duration allowed is 60 seconds.
            start_seconds: The start time of the input audio in seconds. The maximum duration allowed is 60 seconds.
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_talking_photo.create(
            assets={
                "audio_file_path": "api-assets/id/1234.mp3",
                "image_file_path": "api-assets/id/1234.png",
            },
            end_seconds=15.0,
            start_seconds=0.0,
            name="Talking Photo image",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "style": style,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
            },
            dump_with=params._SerializerV1AiTalkingPhotoCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-talking-photo",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiTalkingPhotoCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiTalkingPhotoClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1AiTalkingPhotoCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        style: typing.Union[
            typing.Optional[params.V1AiTalkingPhotoCreateBodyStyle], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiTalkingPhotoCreateResponse:
        """
        AI Talking Photo

        Create a talking photo from an image and audio or text input.

        POST /v1/ai-talking-photo

        Args:
            name: The name of image
            style: Attributes used to dictate the style of the output
            assets: Provide the assets for creating a talking photo
            end_seconds: The end time of the input audio in seconds. The maximum duration allowed is 60 seconds.
            start_seconds: The start time of the input audio in seconds. The maximum duration allowed is 60 seconds.
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_talking_photo.create(
            assets={
                "audio_file_path": "api-assets/id/1234.mp3",
                "image_file_path": "api-assets/id/1234.png",
            },
            end_seconds=15.0,
            start_seconds=0.0,
            name="Talking Photo image",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "style": style,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
            },
            dump_with=params._SerializerV1AiTalkingPhotoCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-talking-photo",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiTalkingPhotoCreateResponse,
            request_options=request_options or default_request_options(),
        )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiGifGeneratorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        style: params.V1AiGifGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiGifGeneratorCreateResponse:
        """
        AI GIFs

        Create an AI GIF. Each GIF costs 50 credits.

        POST /v1/ai-gif-generator

        Args:
            name: The name of gif
            style: V1AiGifGeneratorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_gif_generator.create(
            style={"prompt": "Cute dancing cat, pixel art"}, name="Ai Gif gif"
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "style": style},
            dump_with=params._SerializerV1AiGifGeneratorCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-gif-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiGifGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiGifGeneratorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        style: params.V1AiGifGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiGifGeneratorCreateResponse:
        """
        AI GIFs

        Create an AI GIF. Each GIF costs 50 credits.

        POST /v1/ai-gif-generator

        Args:
            name: The name of gif
            style: V1AiGifGeneratorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_gif_generator.create(
            style={"prompt": "Cute dancing cat, pixel art"}, name="Ai Gif gif"
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "style": style},
            dump_with=params._SerializerV1AiGifGeneratorCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-gif-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiGifGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing
import typing_extensions


class V1AutoSubtitleGeneratorCreateBodyStyleCustomConfig(typing_extensions.TypedDict):
    """
    Custom subtitle configuration.
    """

    font: typing_extensions.NotRequired[str]
    """
    Font name from Google Fonts. Not all fonts support all languages or character sets. 
    We recommend verifying language support and appearance directly on https://fonts.google.com before use.
    """

    font_size: typing_extensions.NotRequired[float]
    """
    Font size in pixels. If not provided, the font size is automatically calculated based on the video resolution.
    """

    font_style: typing_extensions.NotRequired[str]
    """
    Font style (e.g., normal, italic, bold)
    """

    highlighted_text_color: typing_extensions.NotRequired[str]
    """
    Color used to highlight the current spoken text
    """

    horizontal_position: typing_extensions.NotRequired[str]
    """
    Horizontal alignment of the text (e.g., left, center, right)
    """

    stroke_color: typing_extensions.NotRequired[str]
    """
    Stroke (outline) color of the text
    """

    stroke_width: typing_extensions.NotRequired[float]
    """
    Width of the text stroke in pixels. If `stroke_color` is provided, but `stroke_width` is not, the `stroke_width` will be calculated automatically based on the font size.
    """

    text_color: typing_extensions.NotRequired[str]
    """
    Primary text color in hex format
    """

    vertical_position: typing_extensions.NotRequired[str]
    """
    Vertical alignment of the text (e.g., top, center, bottom)
    """


class _SerializerV1AutoSubtitleGeneratorCreateBodyStyleCustomConfig(pydantic.BaseModel):
    """
    Serializer for V1AutoSubtitleGeneratorCreateBodyStyleCustomConfig handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    font: typing.Optional[str] = pydantic.Field(alias="font", default=None)
    font_size: typing.Optional[float] = pydantic.Field(alias="font_size", default=None)
    font_style: typing.Optional[str] = pydantic.Field(alias="font_style", default=None)
    highlighted_text_color: typing.Optional[str] = pydantic.Field(
        alias="highlighted_text_color", default=None
    )
    horizontal_position: typing.Optional[str] = pydantic.Field(
        alias="horizontal_position", default=None
    )
    stroke_color: typing.Optional[str] = pydantic.Field(
        alias="stroke_color", default=None
    )
    stroke_width: typing.Optional[float] = pydantic.Field(
        alias="stroke_width", default=None
    )
    text_color: typing.Optional[str] = pydantic.Field(alias="text_color", default=None)
    vertical_position: typing.Optional[str] = pydantic.Field(
        alias="vertical_position", default=None
    )
